@@ -10,7 +10,7 @@ use Carp;
 use IO::Handle;
 use IO::Zlib;
 
-our $VERSION = '0.078'; # VERSION
+our $VERSION = '0.081'; # VERSION
 
 has fh              => ( is => 'rw' );
 has mode            => ( is => 'rw', default => '<' );
@@ -41,7 +41,10 @@ sub _build__fhi {
     while (1) {
       my $l = <$fh>;
       if ( defined($l) ) {
-        $l =~ s/\r\n/\n/;
+        # handle DOS format
+        #$l =~ s/\r\n$/\n/;
+        # this is 2x as fast
+        substr( $l, -2, 1, '' ) if ( substr( $l, -2, 1 ) eq "\r" );
         chomp $l;
       } else {
         return;
